@@ -1,4 +1,4 @@
-#include "cheese-config.h"
+#include "config.h"
 
 #include <stdlib.h>
 #include <glib/gi18n.h>
